@@ -535,7 +535,7 @@ enum trace_flag_type {
 int pevent_register_comm(struct pevent *pevent, const char *comm, int pid);
 int pevent_register_function(struct pevent *pevent, char *name,
 			     unsigned long long addr, char *mod);
-int pevent_register_print_string(struct pevent *pevent, const char *fmt,
+int pevent_register_print_string(struct pevent *pevent, char *fmt,
 				 unsigned long long addr);
 int pevent_pid_is_registered(struct pevent *pevent, int pid);
 
