@@ -50,7 +50,10 @@ static char *cputype_name[] = {
 	[CPU_HASWELL] = "Haswell",
 	[CPU_HASWELL_EPEX] = "Intel Xeon v3 (Haswell) EP/EX",
 	[CPU_BROADWELL] = "Broadwell",
+	[CPU_BROADWELL_DE] = "Broadwell DE",
+	[CPU_BROADWELL_EPEX] = "Broadwell EP/EX",
 	[CPU_KNIGHTS_LANDING] = "Knights Landing",
+	[CPU_KNIGHTS_MILL] = "Knights Mill",
 };
 
 static enum cputype select_intel_cputype(struct ras_events *ras)
@@ -90,10 +93,16 @@ static enum cputype select_intel_cputype(struct ras_events *ras)
 			return CPU_HASWELL;
 		else if (mce->model == 0x3f)
 			return CPU_HASWELL_EPEX;
+		else if (mce->model == 0x56)
+			return CPU_BROADWELL_DE;
+		else if (mce->model == 0x4f)
+			return CPU_BROADWELL_EPEX;
 		else if (mce->model == 0x3d)
 			return CPU_BROADWELL;
 		else if (mce->model == 0x57)
 			return CPU_KNIGHTS_LANDING;
+		else if (mce->model == 0x85)
+			return CPU_KNIGHTS_MILL;
 
 		if (mce->model > 0x1a) {
 			log(ALL, LOG_INFO,
@@ -222,6 +231,8 @@ int register_mce_handler(struct ras_events *ras, unsigned ncpus)
 	case CPU_SANDY_BRIDGE_EP:
 	case CPU_IVY_BRIDGE_EPEX:
 	case CPU_HASWELL_EPEX:
+	case CPU_KNIGHTS_LANDING:
+	case CPU_KNIGHTS_MILL:
 		set_intel_imc_log(mce->cputype, ncpus);
 	default:
 		break;
